ProvisionError

Enum ProvisionError 

pub enum ProvisionError {
    Incompatible {
        client: String,
        worker: String,
    },
    UnknownKind(String),
    Broken(String),
}
Why a worker will not let itself be provisioned.

Variants



Incompatible

The client and the worker cannot understand each other.

Fields

client: String

How the client identified itself.

worker: String

And what there is on this side.



UnknownKind(String)

A kind of artifact this worker cannot interpret.



Broken(String)

It knew how to interpret it and could not.