pub enum ProvisionError {
Incompatible {
client: String,
worker: String,
},
UnknownKind(String),
Broken(String),
}Expand description
Why a worker will not let itself be provisioned.
Variants
Incompatible
The client and the worker cannot understand each other.
Fields
UnknownKind(String)
A kind of artifact this worker cannot interpret.
Broken(String)
It knew how to interpret it and could not.